@@ -248,14 +248,6 @@ class _Scanner:
                                   contains='No hits found')
             read_and_call_while(uhandle, consumer.noevent, blank=1)
 
-            #Psiblast can repeat the Searching...No hits found section
-            if attempt_read_and_call(uhandle, consumer.noevent,
-                                     start='Searching'):
-                read_and_call_while(uhandle, consumer.noevent, blank=1)
-                read_and_call(uhandle, consumer.noevent,
-                              contains='No hits found')
-                read_and_call_while(uhandle, consumer.noevent, blank=1)
-            
             consumer.end_descriptions()
             # Stop processing.
             return
@@ -1018,7 +1010,7 @@ class _HSPConsumer:
         # added the end group and the -? to allow parsing
         # of BLAT output in BLAST format.
         start, seq, end = _re_search(
-            r"Sbjct: (-?\d+)\s*(.+) (-?\d+)", line,
+            r"Sbjct:\s*(-?\d+)\s*(.+) (-?\d+)", line,
             "I could not find the sbjct in line\n%s" % line)
         #mikep 26/9/00
         #On occasion, there is a blast hit with no subject match
@@ -1414,9 +1406,9 @@ class Iterator:
     def __iter__(self):
         return iter(self.next, None)
 
-def blastall(blastcmd, program, database, infile, **keywds):
-    """blastall(blastcmd, program, database, infile, **keywds) ->
-    read, error Undohandles
+def blastall(blastcmd, program, database, infile, align_view='7', **keywds):
+    """blastall(blastcmd, program, database, infile, align_view='7', **keywds)
+    -> read, error Undohandles
     
     Execute and retrieve data from blastall.  blastcmd is the command
     used to launch the 'blastall' executable.  program is the blast program
@@ -1426,6 +1418,8 @@ def blastall(blastcmd, program, database, infile, **keywds):
 
     You may pass more parameters to **keywds to change the behavior of
     the search.  Otherwise, optional values will be chosen by blastall.
+    The Blast output is by default in XML format. Use the align_view keyword
+    for output in a different format.
     
         Scoring
     matrix              Matrix to use.
@@ -1453,12 +1447,13 @@ def blastall(blastcmd, program, database, infile, **keywds):
     believe_query       Believe the query defline.  T/F
     restrict_gi         Restrict search to these GI's.
     nprocessors         Number of processors to use.
+    oldengine           Force use of old engine T/F
 
         Formatting
     html                Produce HTML output?  T/F
     descriptions        Number of one-line descriptions.
     alignments          Number of alignments.
-    align_view          Alignment view.  Integer 0-6.
+    align_view          Alignment view.  Integer 0-11, passed as a string.
     show_gi             Show GI's in deflines?  T/F
     seqalign_file       seqalign file to output.
 
@@ -1490,6 +1485,7 @@ def blastall(blastcmd, program, database, infile, **keywds):
         'believe_query' : '-J',
         'restrict_gi' : '-l',
         'nprocessors' : '-a',
+        'oldengine' : '-V',
 
         'html' : '-T',
         'descriptions' : '-v',
@@ -1507,6 +1503,7 @@ def blastall(blastcmd, program, database, infile, **keywds):
     params.extend([att2param['program'], program])
     params.extend([att2param['database'], database])
     params.extend([att2param['infile'], infile])
+    params.extend([att2param['align_view'], align_view])
 
     for attr in keywds.keys():
         params.extend([att2param[attr], str(keywds[attr])])
@@ -1516,8 +1513,8 @@ def blastall(blastcmd, program, database, infile, **keywds):
     return File.UndoHandle(r), File.UndoHandle(e)
 
 
-def blastpgp(blastcmd, database, infile, **keywds):
-    """blastpgp(blastcmd, database, infile, **keywds) ->
+def blastpgp(blastcmd, database, infile, align_view='7', **keywds):
+    """blastpgp(blastcmd, database, infile, align_view='7', **keywds) ->
     read, error Undohandles
     
     Execute and retrieve data from blastpgp.  blastcmd is the command
@@ -1527,6 +1524,8 @@ def blastpgp(blastcmd, database, infile, **keywds):
 
     You may pass more parameters to **keywds to change the behavior of
     the search.  Otherwise, optional values will be chosen by blastpgp.
+    The Blast output is by default in XML format. Use the align_view keyword
+    for output in a different format.
 
         Scoring
     matrix              Matrix to use.
@@ -1565,7 +1564,7 @@ def blastpgp(blastcmd, database, infile, **keywds):
     html                Produce HTML output?  T/F
     descriptions        Number of one-line descriptions.
     alignments          Number of alignments.
-    align_view          Alignment view.  Integer 0-6.
+    align_view          Alignment view.  Integer 0-11, passed as a string.
     show_gi             Show GI's in deflines?  T/F
     seqalign_file       seqalign file to output.
     align_outfile       Output file for alignment.
@@ -1629,6 +1628,7 @@ def blastpgp(blastcmd, database, infile, **keywds):
 
     params.extend([att2param['database'], database])
     params.extend([att2param['infile'], infile])
+    params.extend([att2param['align_view'], align_view])
 
     for attr in keywds.keys():
         params.extend([att2param[attr], str(keywds[attr])])
