@@ -548,7 +548,7 @@ class Nexus(object):
             #3 Assume we have a file object
             if hasattr(input,'read'): # file objects or StringIO objects
                 file_contents=input.read()
-                if input.name:
+                if hasattr(input,"name") and input.name:
                     self.filename=input.name
                 else:
                     self.filename='Unknown_nexus_file'
@@ -1167,7 +1167,7 @@ class Nexus(object):
         if not filename:
             filename=self.filename
         if [t for t in delete if not self._check_taxlabels(t)]:
-            raise NexusError, 'Unknwon taxa: %s' % ', '.join(sets.Set(delete).difference(sets.Set(self.taxlabels)))
+            raise NexusError, 'Unknown taxa: %s' % ', '.join(sets.Set(delete).difference(sets.Set(self.taxlabels)))
         if interleave_by_partition:
             if not interleave_by_partition in self.charpartitions:
                 raise NexusError, 'Unknown partition: '+interleave_by_partition
