@@ -11,6 +11,9 @@ http://www.expasy.ch/sprot/sprot-top.html
 Tested with:
 Release 37, Release 38, Release 39
 
+Limited testing with:
+Release 51
+
 
 Classes:
 Record             Holds SwissProt data.
@@ -62,6 +65,8 @@ class Record:
     organism_classification  The taxonomy classification.  List of strings.
                              (http://www.ncbi.nlm.nih.gov/Taxonomy/)
     taxonomy_id       A list of NCBI taxonomy id's.
+    host_organism     A list of NCBI taxonomy id's of the hosts of a virus,
+                      if any.
     references        List of Reference objects.
     comments          List of strings.
     cross_references  List of tuples (db, id1[, id2][, id3]).  See the docs.
@@ -91,6 +96,7 @@ class Record:
         self.organelle = ''
         self.organism_classification = []
         self.taxonomy_id = []
+        self.host_organism = []
         self.references = []
         self.comments = []
         self.cross_references = []
@@ -402,6 +408,10 @@ class _Scanner:
         self._scan_line('OX', uhandle, consumer.taxonomy_id,
                         any_number=1)
 
+    def _scan_oh(self, uhandle, consumer):
+        # viral host organism. introduced after SwissProt 39.
+        self._scan_line('OH', uhandle, consumer.organism_host, any_number=1)
+
     def _scan_reference(self, uhandle, consumer):
         while 1:
             if safe_peekline(uhandle)[:2] != 'RN':
@@ -488,6 +498,7 @@ class _Scanner:
         _scan_og,
         _scan_oc,
         _scan_ox,
+        _scan_oh,
         _scan_reference,
         _scan_cc,
         _scan_dr,
@@ -516,18 +527,39 @@ class _RecordConsumer(AbstractConsumer):
 
     def identification(self, line):
         cols = line.split()
-        self.data.entry_name = cols[1]
-        self.data.data_class = self._chomp(cols[2])    # don't want ';'
-        self.data.molecule_type = self._chomp(cols[3]) # don't want ';'
-        self.data.sequence_length = int(cols[4])
-
+        #Prior to release 51, included with MoleculeType:
+        #ID   EntryName DataClass; MoleculeType; SequenceLength.
+        #
+        #Newer files lack the MoleculeType:
+        #ID   EntryName DataClass; SequenceLength.
+        #
+        #Note that cols is split on white space, so the length
+        #should become two fields (number and units)
+        if len(cols) == 6 :
+            self.data.entry_name = cols[1]
+            self.data.data_class = self._chomp(cols[2])    # don't want ';'
+            self.data.molecule_type = self._chomp(cols[3]) # don't want ';'
+            self.data.sequence_length = int(cols[4])
+        elif len(cols) == 5 :
+            self.data.entry_name = cols[1]
+            self.data.data_class = self._chomp(cols[2])    # don't want ';'
+            self.data.molecule_type = None
+            self.data.sequence_length = int(cols[3])
+        else :
+            #Should we print a warning an continue?
+            raise SyntaxError("ID line has unrecognised format:\n"+line)
+        
         # data class can be 'STANDARD' or 'PRELIMINARY'
         # ws:2001-12-05 added IPI
-        if self.data.data_class not in ['STANDARD', 'PRELIMINARY', 'IPI']: 
+        # pjc:2006-11-02 added 'Reviewed' and 'Unreviewed'
+        if self.data.data_class not in ['STANDARD', 'PRELIMINARY', 'IPI',
+                                        'Reviewed', 'Unreviewed']: 
             raise SyntaxError, "Unrecognized data class %s in line\n%s" % \
                   (self.data.data_class, line)
         # molecule_type should be 'PRT' for PRoTein
-        if self.data.molecule_type != 'PRT':
+        # Note that has been removed in recent releases (set to None)
+        if self.data.molecule_type is not None \
+        and self.data.molecule_type != 'PRT':
             raise SyntaxError, "Unrecognized molecule type %s in line\n%s" % \
                   (self.data.molecule_type, line)
     
@@ -538,7 +570,8 @@ class _RecordConsumer(AbstractConsumer):
     
     def date(self, line):
         uprline = string.upper(line)
-
+        cols = line.rstrip().split()
+                
         if uprline.find('CREATED') >= 0 \
         or uprline.find('LAST SEQUENCE UPDATE') >= 0 \
         or uprline.find('LAST ANNOTATION UPDATE') >= 0:
@@ -566,7 +599,6 @@ class _RecordConsumer(AbstractConsumer):
                     "Could not find Rel. in DT line: %s" % (line)
             version_index = rel_index + 1
             # get the version information
-            cols = line.split()
             str_version = self._chomp(cols[version_index])
             # no version number
             if str_version == '':
@@ -586,7 +618,6 @@ class _RecordConsumer(AbstractConsumer):
                 self.data.annotation_update = cols[1], version
             else:
                 assert False, "Shouldn't reach this line!"
-                raise SyntaxError, "I don't understand the date line %s" % line
         elif uprline.find('INTEGRATED INTO') >= 0 \
         or uprline.find('SEQUENCE VERSION') >= 0 \
         or uprline.find('ENTRY VERSION') >= 0:
@@ -606,11 +637,27 @@ class _RecordConsumer(AbstractConsumer):
             # DT   01-APR-2004, entry version 14.
             #
             #This is a new style DT line...
-            print "WARNING - Ignoring line: " + line
-            # TODO - Expose the new version and database information
-            #        to the record object.
+
+            # The date should be in string cols[1]
+            # Get the version number if there is one.
+            # For the three DT lines above: 0, 3, 14
+            try:
+                version = int(cols[-1])
+            except ValueError :
+                version = 0
+
+            # Re-use the historical property names, even though
+            # the meaning has changed slighty:
+            if uprline.find("INTEGRATED") >= 0:
+                self.data.created = cols[1], version
+            elif uprline.find('SEQUENCE VERSION') >= 0:
+                self.data.sequence_update = cols[1], version
+            elif uprline.find( 'ENTRY VERSION') >= 0:
+                self.data.annotation_update = cols[1], version
+            else:
+                assert False, "Shouldn't reach this line!"
         else:
-            raise SyntaxError, "I don't understand the date line %s" % line        
+            raise SyntaxError, "I don't understand the date line %s" % line
     
     def description(self, line):
         self.data.description = self.data.description + line[5:]
@@ -651,7 +698,20 @@ class _RecordConsumer(AbstractConsumer):
         else:
             ids = line.split(',')
         self.data.taxonomy_id.extend([id.strip() for id in ids])
-    
+
+    def organism_host(self, line):
+        # Line type OH (Organism Host) for viral hosts
+        # same code as in taxonomy_id()
+        line = self._chomp(line[5:].rstrip())
+        index = line.find('=')
+        if index >= 0:
+            descr = line[:index]
+            assert descr == "NCBI_TaxID", "Unexpected taxonomy type %s" % descr
+            ids = line[index+1:].split(',')
+        else:
+            ids = line.split(',')
+        self.data.host_organism.extend([id.strip() for id in ids])
+        
     def reference_number(self, line):
         rn = line[5:].rstrip()
         assert rn[0] == '[' and rn[-1] == ']', "Missing brackets %s" % rn
@@ -710,28 +770,25 @@ class _RecordConsumer(AbstractConsumer):
         # reported by edvard@farmasi.uit.no
         # and these can be more complicated like:
         # RX   MEDLINE=95385798; PubMed=7656980;
+        # RX   PubMed=15060122; DOI=10.1136/jmg 2003.012781;
         # We look for these cases first and deal with them
-        if line.find( "=") != -1:
-            cols = line.split()
-            assert len(cols) > 1, "I don't understand RX line %s" % line
-
-            for info_col in cols[1:]:
-                id_cols = info_col.split("=")
-                if len(id_cols) == 2:
-                    self.data.references[-1].references.append(
-                        (self._chomp(id_cols[0]), self._chomp(id_cols[1])))
-                else:
-                    raise AssertionError("I don't understand RX line %s"
-                                         % line)
+        if line.find("=") != -1:
+            cols = line[2:].split("; ")
+            cols = [x.strip() for x in cols]
+            cols = [x for x in cols if x]
+            for col in cols:
+                x = col.split("=")
+                assert len(x) == 2, "I don't understand RX line %s" % line
+                key, value = self._chomp(x[0]), self._chomp(x[1])
+                ref = self.data.references[-1].references
+                ref.append((key, value))
         # otherwise we assume we have the type 'RX   MEDLINE; 85132727.'
         else:
             cols = line.split()
             # normally we split into the three parts
-            if len(cols) == 3:
-                self.data.references[-1].references.append(
-                    (self._chomp(cols[1]), self._chomp(cols[2])))
-            else:
-                raise AssertionError("I don't understand RX line %s" % line)
+            assert len(cols) == 3, "I don't understand RX line %s" % line
+            self.data.references[-1].references.append(
+                (self._chomp(cols[1]), self._chomp(cols[2])))
     
     def reference_author(self, line):
         assert self.data.references, "RA: missing RN"
@@ -961,3 +1018,4 @@ def index_file(filename, indexname, rec2key=None):
             raise KeyError, "duplicate key %s found" % key
 
         index[key] = start, length
+        
